@@ -1,7 +1,5 @@
 from __future__ import absolute_import, division, print_function
 
-import warnings
-
 import sys
 import pytest
 import numpy as np
@@ -9,7 +7,7 @@ from mock import MagicMock
 from numpy.testing import assert_allclose, assert_array_equal
 
 from glue.core.component import CategoricalComponent
-from glue.core.data import Data
+from glue.core.data import BaseCartesianData, Data
 from glue.core import data_factories as df
 from glue.config import data_factory
 from glue.tests.helpers import requires_astropy, make_file, requires_qt
@@ -111,14 +109,13 @@ def test_csv_pandas_factory():
         d = df.load_data(fname, factory=df.pandas_read_table)
     assert d['a'].dtype == np.int64
     assert d['b'].dtype == np.float
-    assert d['c'].dtype == np.float
+    assert d['c'].dtype == np.object
     cat_comp = d.find_component_id('c')
     assert isinstance(d.get_component(cat_comp), CategoricalComponent)
     correct_cats = np.unique(np.asarray(['some', 'categorical',
                                          'data', 'here',
                                          '', '', '']))
-    np.testing.assert_equal(d.get_component(cat_comp).categories,
-                            correct_cats)
+    np.testing.assert_equal(d[cat_comp].categories, correct_cats)
     cat_comp = d.find_component_id('d')
     assert isinstance(d.get_component(cat_comp), CategoricalComponent)
 
@@ -137,11 +134,11 @@ def test_dtype_float():
     assert d['a'].dtype == np.float
 
 
-def test_dtype_float_on_categorical():
+def test_dtype_str_on_categorical():
     data = b'# a, b\nf, 1 \nr, 2 \nk, 3'
     with make_file(data, '.csv') as fname:
         d = df.load_data(fname)
-    assert d['a'].dtype == np.float
+    assert d['a'].dtype.kind in 'SU'
 
 
 def test_dtype_badtext():
@@ -197,10 +194,8 @@ def test_data_reload_no_file():
         d = df.load_data(fname)
 
     # file no longer exists
-    with warnings.catch_warnings(record=True) as w:
+    with pytest.warns(UserWarning, match='Could not reload'):
         d._load_log.reload()
-    assert len(w) == 1
-    assert str(w[0].message).startswith('Could not reload')
 
     assert_array_equal(d['a'], [0, 2, 3, 5, 7])
 
@@ -214,10 +209,8 @@ def test_data_reload_shape_change():
         with open(fname, 'w') as f2:
             f2.write('#a, b\n0, 0\n0, 0\n0, 0\n0, 0')
 
-        with warnings.catch_warnings(record=True) as w:
+        with pytest.warns(UserWarning, match='Cannot refresh data -- data shape changed'):
             d._load_log.reload()
-        assert len(w) == 1
-        assert str(w[0].message) == 'Cannot refresh data -- data shape changed'
 
     assert_array_equal(d['a'], [0, 2, 3, 5, 7])
     assert d.coords is coords_old
@@ -249,10 +242,8 @@ def test_file_watch_os_error():
     with make_file(b'test', 'csv') as fname:
         fw = df.FileWatcher(fname, cb)
 
-    with warnings.catch_warnings(record=True) as w:
+    with pytest.warns(UserWarning, match='Cannot access'):
         fw.check_for_changes()
-    assert len(w) == 1
-    assert str(w[0].message).startswith('Cannot access')
 
     assert cb.call_count == 0
 
@@ -278,10 +269,48 @@ def test_ambiguous_format(tmpdir):
     # Should raise a warning and pick the highest priority one in alphabetical
     # order
 
-    with warnings.catch_warnings(record=True) as w:
+    with pytest.warns(UserWarning, match="Multiple data factories matched the input: 'a', 'b'. Choosing 'a'."):
         factory = df.find_factory(filename)
 
-    assert len(w) == 1
-    assert str(w[0].message) == "Multiple data factories matched the input: 'a', 'b'. Choosing 'a'."
-
     assert factory is reader2
+
+
+def test_basedata(tmpdir):
+
+    # Regression test for a bug that caused load_data to fail if a data
+    # factory returned a BaseData (but not Data) subclass, due to the
+    # LoadLog expecting a Data object
+
+    class BigData(BaseCartesianData):
+
+        def get_kind(self):
+            pass
+
+        def compute_histogram(self):
+            pass
+
+        def compute_statistic(self):
+            pass
+
+        def get_mask(self):
+            pass
+
+        @property
+        def shape(self):
+            pass
+
+        @property
+        def main_components(self):
+            return []
+
+    @data_factory('bigdata', identifier=df.has_extension('bigdata'), priority=34)
+    def reader(filename):
+        return BigData()
+
+    filename = tmpdir.join('test.bigdata').strpath
+    with open(filename, 'w') as f:
+        f.write('Camelot!')
+
+    d = df.load_data(filename)
+
+    assert isinstance(d, BigData)
